==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.tools.common/src/com/openexchange/office/tools/common/string/StringHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.tools.common.string;

import org.apache.commons.lang3.StringUtils;

public class StringHelper
{
    //-------------------------------------------------------------------------
	private StringHelper() {}

    //-------------------------------------------------------------------------
    private static final char[] hexArray = { '0','1','2', '3','4','5','6','7','8','9','A','B','C', 'D','E','F' };

    //-------------------------------------------------------------------------
    public static final int MAX_BYTES_LENGTH = 1024;

    //-------------------------------------------------------------------------
	public static String toHexString(final byte[] aBytes)
    {
		return createHexString(aBytes, aBytes.length);
    }

    //-------------------------------------------------------------------------
	public static String toHexString(final byte[] aBytes, boolean bTruncate)
    {
		return createHexString(aBytes, bTruncate ? MAX_BYTES_LENGTH : aBytes.length);
    }

    //-------------------------------------------------------------------------
	public static boolean isNotEmptyAndEqual(String s1, String s2) {
		if ((s1 != null) && (s2 != null) && StringUtils.isNotEmpty(s1) && StringUtils.isNotEmpty(s2)) {
			return s1.equals(s2);
		}
		return false;
	}

    //-------------------------------------------------------------------------
	private static String createHexString(final byte[] aBytes, int nMaxLength)
    {
        final char[] aHexChars = new char[Math.min(nMaxLength, aBytes.length) * 2];

        for ( int i = 0; i < aBytes.length; i++ )
        {
            final int b = aBytes[i] & 0xFF;
            aHexChars[i*2]   = hexArray[b >>> 4 ];
            aHexChars[i*2+1] = hexArray[b & 0x0F];
        }

        return new String(aHexChars);
    }

}

==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.tools.common/src/com/openexchange/office/tools/common/string/StringHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.tools.common.string;

import java.util.HashSet;
import java.util.Set;
import java.util.function.IntPredicate;
import org.apache.commons.lang3.StringUtils;

public class StringHelper
{
    //-------------------------------------------------------------------------
	private StringHelper() {}

    //-------------------------------------------------------------------------
    private static final char[] hexArray = { '0','1','2', '3','4','5','6','7','8','9','A','B','C', 'D','E','F' };
    private static final IntPredicate isHexChar = c -> ((c >= '0' && c <= '9') || (c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f'));

    //-------------------------------------------------------------------------
    public static final int MAX_BYTES_LENGTH = 1024;
    public static final String STR_PLACEHOLDER = "{}";

    //-------------------------------------------------------------------------
    public static String replacePlaceholdersWithArgs(String msg, String...values)  {
    	if (msg == null)
    		throw new IllegalArgumentException("Placeholder string must not be null!");

    	final StringBuffer tmp = new StringBuffer(msg);
    	int valIndex = 0;
    	int index = 0;
    	while ((index = tmp.indexOf(STR_PLACEHOLDER, index)) > 0) {
    		String tmpValue = (values.length > valIndex) ? values[valIndex] : "null";
    		String value = (tmpValue == null) ? "null" : tmpValue;
    		tmp.replace(index, index + STR_PLACEHOLDER.length() , value);
    		index += value.length();
    		++valIndex;
    	}

    	return tmp.toString();
    }

    //-------------------------------------------------------------------------
    public static boolean isHexString(String isHex) {
        if (StringUtils.isNotEmpty(isHex)) {
            return isHex.chars().allMatch(isHexChar);
        }
        return false;
    }

    //-------------------------------------------------------------------------
	public static String toHexString(final byte[] aBytes) {
		return createHexString(aBytes, aBytes.length);
    }

    //-------------------------------------------------------------------------
	public static String toHexString(final byte[] aBytes, boolean bTruncate)
    {
		return createHexString(aBytes, bTruncate ? MAX_BYTES_LENGTH : aBytes.length);
    }

    //-------------------------------------------------------------------------
	public static boolean isNotEmptyAndEqual(String s1, String s2) {
		if ((s1 != null) && (s2 != null) && StringUtils.isNotEmpty(s1) && StringUtils.isNotEmpty(s2)) {
			return s1.equals(s2);
		}
		return false;
	}

    //-------------------------------------------------------------------------
	private static String createHexString(final byte[] aBytes, int nMaxLength)
    {
        final char[] aHexChars = new char[Math.min(nMaxLength, aBytes.length) * 2];

        for ( int i = 0; i < aBytes.length; i++ )
        {
            final int b = aBytes[i] & 0xFF;
            aHexChars[i*2]   = hexArray[b >>> 4 ];
            aHexChars[i*2+1] = hexArray[b & 0x0F];
        }

        return new String(aHexChars);
    }

    //-------------------------------------------------------------------------
	private static Set<Character> asSet(char[] chars) {
        final Set<Character> result = new HashSet<>();
        if ((chars != null) && (chars.length > 0)){
            for (char c : chars) {
                result.add(c);
            }
        }
        return result;
    }

}
